@@ -1,20 +1,20 @@
 #
 # This file is part of Dist-Zilla-Plugin-WSDL
 #
-# This software is copyright (c) 2010 by Mark Gardner.
+# This software is copyright (c) 2011 by GSI Commerce.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use 5.008_008;    ## no critic (RequireExplicitPackage)
-use utf8;         ## no critic (RequireExplicitPackage)
-use strict;       ## no critic (RequireExplicitPackage)
-use warnings;     ## no critic (RequireExplicitPackage)
+use 5.008_008;
+use strict;
+use warnings;
+use utf8;
 
 package Dist::Zilla::Plugin::WSDL;
 
 BEGIN {
-    $Dist::Zilla::Plugin::WSDL::VERSION = '0.102600';
+    $Dist::Zilla::Plugin::WSDL::VERSION = '0.200';
 }
 
 # ABSTRACT: WSDL to Perl classes when building your dist
@@ -29,6 +29,8 @@ use MooseX::Types::Moose qw(ArrayRef Bool HashRef Str);
 use MooseX::Types::URI 'Uri';
 use Path::Class;
 use Regexp::DefaultFlags;
+## no critic (RequireDotMatchAnything,RequireExtendedFormatting)
+## no critic (RequireLineBoundaryMatching)
 use SOAP::WSDL::Expat::WSDLParser;
 use SOAP::WSDL::Factory::Generator;
 use Dist::Zilla::Plugin::WSDL::Types qw(ClassPrefix);
@@ -149,7 +151,7 @@ sub before_build {
         my $file_path = $self->zilla->root->file( $file->name() );
         $file_path->dir->mkpath();
         my $fh = $file_path->openw();
-        print $fh $file->content();
+        print {$fh} $file->content();
         close $fh;
     }
     return;
@@ -159,13 +161,16 @@ sub before_build {
 
 =pod
 
+=for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
+cpants kwalitee diff irc mailto metadata placeholders
+
 =head1 NAME
 
 Dist::Zilla::Plugin::WSDL - WSDL to Perl classes when building your dist
 
 =head1 VERSION
 
-version 0.102600
+version 0.200
 
 =head1 DESCRIPTION
 
@@ -210,29 +215,94 @@ WSDL and gathers them into the C<lib> directory of your distribution.
 
 =for Pod::Coverage mvp_multivalue_args
 
-=head1 INSTALLATION
+=head1 SUPPORT
 
-See perlmodinstall for information and options on installing Perl modules.
+=head2 Perldoc
 
-=head1 BUGS AND LIMITATIONS
+You can find documentation for this module with the perldoc command.
 
-No bugs have been reported.
+  perldoc Dist::Zilla::Plugin::WSDL
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+=head2 Websites
 
-=head1 AVAILABILITY
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
 
-The project homepage is L<http://github.com/mjg/Dist-Zilla-Plugin-WSDL/tree>.
+=over 4
 
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-Plugin-WSDL/>.
+=item *
 
-The development version lives at L<http://github.com/mjg/Dist-Zilla-Plugin-WSDL.git>
-and may be cloned from L<git://github.com/mjg/Dist-Zilla-Plugin-WSDL.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Dist-Zilla-Plugin-WSDL>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+
+L<http://annocpan.org/dist/Dist-Zilla-Plugin-WSDL>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-WSDL>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/Dist-Zilla-Plugin-WSDL>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/D/Dist-Zilla-Plugin-WSDL>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+
+L<http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-WSDL>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Dist::Zilla::Plugin::WSDL>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the web
+interface at L<https://github.com/mjgardner/Dist-Zilla-Plugin-WSDL/issues>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/mjgardner/Dist-Zilla-Plugin-WSDL>
+
+  git clone git://github.com/mjgardner/Dist-Zilla-Plugin-WSDL.git
 
 =head1 AUTHOR
 
@@ -240,7 +310,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Mark Gardner.
+This software is copyright (c) 2011 by GSI Commerce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
